filter

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 5, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewEngine

func NewEngine() interfaces.FilterEngine

NewEngine creates a new filter engine

Types

type Engine

type Engine struct{}

Engine implements the FilterEngine interface

func (*Engine) ApplyFilter

func (e *Engine) ApplyFilter(uploads []types.MultipartUpload, filter interfaces.Filter) []types.MultipartUpload

ApplyFilter applies a filter to a list of uploads

func (*Engine) ParseFilter

func (e *Engine) ParseFilter(filterStr string) (interfaces.Filter, error)

ParseFilter parses a filter string into a structured filter

func (*Engine) ValidateFilter

func (e *Engine) ValidateFilter(filterStr string) error

ValidateFilter validates filter syntax without parsing

Jump to